==> cursors_extended-fabric-4.1.2%2B1.21.9-sources.jar: io/github/fishstiz/cursors_extended/mixin/cursorprovider/menus/MerchantScreenMixin.java <==
package io.github.fishstiz.cursors_extended.mixin.cursorprovider.menus;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import io.github.fishstiz.cursors_extended.cursor.CursorTypesExt;
import io.github.fishstiz.cursors_extended.util.CursorTypeUtil;
import net.minecraft.class_11876;
import net.minecraft.class_1728;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_4185;
import net.minecraft.class_492;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Coerce;

@Mixin(class_492.class)
public abstract class MerchantScreenMixin extends AbstractContainerScreenMixin<class_1728> {
    protected MerchantScreenMixin(class_2561 title) {
        super(title);
    }

    @WrapOperation(method = "renderContents", at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/client/gui/screens/inventory/MerchantScreen$TradeOfferButton;isHoveredOrFocused()Z"
    ))
    private boolean setCursorOnHover(@Coerce class_4185 instance, Operation<Boolean> original, @Local(argsOnly = true) class_332 guiGraphics) {
        if (instance.method_49606()) {
            if (instance.method_37303()) {
                guiGraphics.method_74037(CursorTypeUtil.canShift() ? CursorTypesExt.SHIFT : class_11876.field_62455);
            } else {
                guiGraphics.method_74037(class_11876.field_62459);
            }
        }

        return original.call(instance);
    }
}

==> cursors_extended-fabric-4.1.4%2B1.21.11-sources.jar: io/github/fishstiz/cursors_extended/mixin/cursorprovider/menus/MerchantScreenMixin.java <==
package io.github.fishstiz.cursors_extended.mixin.cursorprovider.menus;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import io.github.fishstiz.cursors_extended.CursorsExtended;
import io.github.fishstiz.cursors_extended.cursor.CursorTypesExt;
import io.github.fishstiz.cursors_extended.util.CursorTypeUtil;
import net.minecraft.class_11875;
import net.minecraft.class_11876;
import net.minecraft.class_1728;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_4185;
import net.minecraft.class_492;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Coerce;
import org.spongepowered.asm.mixin.injection.ModifyArg;

@Mixin(class_492.class)
public abstract class MerchantScreenMixin extends AbstractContainerScreenMixin<class_1728> {
    protected MerchantScreenMixin(class_2561 title) {
        super(title);
    }

    @WrapOperation(method = "renderContents", at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/client/gui/screens/inventory/MerchantScreen$TradeOfferButton;isHoveredOrFocused()Z"
    ))
    private boolean setCursorOnHover(@Coerce class_4185 instance, Operation<Boolean> original, @Local(argsOnly = true) class_332 guiGraphics) {
        if (instance.method_49606()) {
            if (instance.method_37303()) {
                guiGraphics.method_74037(CursorTypeUtil.canShift() && CursorsExtended.CONFIG.isLegacyMode()
                        ? CursorTypesExt.SHIFT
                        : class_11876.field_62455
                );
            } else {
                guiGraphics.method_74037(class_11876.field_62459);
            }
        }

        return original.call(instance);
    }

    @ModifyArg(method = "renderScroller", at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/client/gui/GuiGraphics;requestCursor(Lcom/mojang/blaze3d/platform/cursor/CursorType;)V"
    ))
    private class_11875 onRequestCursor(class_11875 cursor) {
        return CursorTypeUtil.applyScrollbarConfig(cursor);
    }
}
